@@ -19,6 +19,9 @@ from neutron_lib.api.definitions import allowedaddresspairs
 from neutron_lib.api.definitions import auto_allocated_topology
 from neutron_lib.api.definitions import availability_zone
 from neutron_lib.api.definitions import availability_zone_filter
+from neutron_lib.api.definitions import bgp
+from neutron_lib.api.definitions import bgp_4byte_asn
+from neutron_lib.api.definitions import bgp_dragentscheduler
 from neutron_lib.api.definitions import bgpvpn
 from neutron_lib.api.definitions import bgpvpn_routes_control
 from neutron_lib.api.definitions import bgpvpn_stdattrs
@@ -33,6 +36,7 @@ from neutron_lib.api.definitions import dns
 from neutron_lib.api.definitions import dns_domain_keywords
 from neutron_lib.api.definitions import dns_domain_ports
 from neutron_lib.api.definitions import dvr
+from neutron_lib.api.definitions import ecmp_routes
 from neutron_lib.api.definitions import empty_string_filtering
 from neutron_lib.api.definitions import expose_l3_conntrack_helper
 from neutron_lib.api.definitions import expose_port_forwarding_in_fip
@@ -89,6 +93,7 @@ from neutron_lib.api.definitions import qos_bw_minimum_ingress
 from neutron_lib.api.definitions import qos_default
 from neutron_lib.api.definitions import qos_gateway_ip
 from neutron_lib.api.definitions import qos_port_network_policy
+from neutron_lib.api.definitions import qos_pps_rule
 from neutron_lib.api.definitions import qos_rule_type_details
 from neutron_lib.api.definitions import qos_rules_alias
 from neutron_lib.api.definitions import rbac_address_groups
@@ -139,6 +144,9 @@ _ALL_API_DEFINITIONS = {
     auto_allocated_topology,
     availability_zone,
     availability_zone_filter,
+    bgp,
+    bgp_4byte_asn,
+    bgp_dragentscheduler,
     bgpvpn,
     bgpvpn_routes_control,
     bgpvpn_stdattrs,
@@ -153,6 +161,7 @@ _ALL_API_DEFINITIONS = {
     dns_domain_keywords,
     dns_domain_ports,
     dvr,
+    ecmp_routes,
     empty_string_filtering,
     expose_l3_conntrack_helper,
     expose_port_forwarding_in_fip,
@@ -209,6 +218,7 @@ _ALL_API_DEFINITIONS = {
     qos_default,
     qos_gateway_ip,
     qos_port_network_policy,
+    qos_pps_rule,
     qos_rule_type_details,
     qos_rules_alias,
     rbac_address_groups,
