@@ -113,6 +113,7 @@ KNOWN_EXTENSIONS = (
     'l3-port-ip-change-not-allowed',
     'logging',
     'metering',
+    'metering_source_and_destination_filters',
     'multi-provider',
     'net-mtu',
     'network-ip-availability',
@@ -129,8 +130,11 @@ KNOWN_EXTENSIONS = (
     'qos-port-network-policy',
     'qos-rules-alias',
     'quotas',
+    'rbac-address-group',
+    'rbac-address-scope',
     'rbac-policies',
     'rbac-security-groups',
+    'rbac-subnetpool',
     'router',
     'router_availability_zone',
     'security-group',
@@ -153,7 +157,7 @@ KNOWN_EXTENSIONS = (
     'trunk',
     'trunk-details',
     # Add here list of extensions with pointers to the project repo, e.g.
-    # 'bgp',  # https://opendev.org/openstack/neutron-dynamic-routing
+    'bgp',  # https://opendev.org/openstack/neutron-dynamic-routing
 
     # https://opendev.org/openstack/neutron-fwaas
     'fwaas',
